==> telepathy-qt4_0.2.1.orig.tar.gz: telepathy-qt4-0.2.1/TelepathyQt4/ready-object.h <==
/*
 * This file is part of TelepathyQt4
 *
 * Copyright (C) 2009 Collabora Ltd. <http://www.collabora.co.uk/>
 * Copyright (C) 2009 Nokia Corporation
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef _TelepathyQt4_ready_object_h_HEADER_GUARD_
#define _TelepathyQt4_ready_object_h_HEADER_GUARD_

#ifndef IN_TELEPATHY_QT4_HEADER
#error IN_TELEPATHY_QT4_HEADER
#endif

#include <TelepathyQt4/Feature>

#include <QObject>

namespace Tp
{

class DBusProxy;
class PendingReady;
class ReadinessHelper;

class TELEPATHY_QT4_EXPORT ReadyObject
{
    Q_DISABLE_COPY(ReadyObject)

public:
    ReadyObject(QObject *object, const Feature &featureCore);
    virtual ~ReadyObject();

    virtual bool isReady(const Features &features = Features()) const;
    virtual PendingReady *becomeReady(const Features &requestedFeatures = Features());

    virtual Features requestedFeatures() const;
    virtual Features actualFeatures() const;
    virtual Features missingFeatures() const;

protected:
    ReadinessHelper *readinessHelper() const;

private:
    struct Private;
    friend struct Private;
    Private *mPriv;
};

} // Tp

#endif

==> telepathy-qt4_0.5.6.orig.tar.gz: telepathy-qt4-0.5.6/TelepathyQt4/ready-object.h <==
/*
 * This file is part of TelepathyQt4
 *
 * Copyright (C) 2009 Collabora Ltd. <http://www.collabora.co.uk/>
 * Copyright (C) 2009 Nokia Corporation
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef _TelepathyQt4_ready_object_h_HEADER_GUARD_
#define _TelepathyQt4_ready_object_h_HEADER_GUARD_

#ifndef IN_TELEPATHY_QT4_HEADER
#error IN_TELEPATHY_QT4_HEADER
#endif

#include <TelepathyQt4/Feature>

#include <QObject>

namespace Tp
{

class DBusProxy;
class PendingReady;
class ReadinessHelper;
class RefCounted;

class TELEPATHY_QT4_EXPORT ReadyObject
{
    Q_DISABLE_COPY(ReadyObject)

public:
    ReadyObject(RefCounted *object, const Feature &featureCore);
    ReadyObject(DBusProxy *proxy, const Feature &featureCore);
    virtual ~ReadyObject();

    virtual bool isReady(const Features &features = Features()) const;
    virtual PendingReady *becomeReady(const Features &requestedFeatures = Features());

    virtual Features requestedFeatures() const;
    virtual Features actualFeatures() const;
    virtual Features missingFeatures() const;

protected:
    ReadinessHelper *readinessHelper() const;

private:
    struct Private;
    friend struct Private;
    Private *mPriv;
};

} // Tp

#endif
